==> wormux_0.7.9.orig.tar.gz: wormux-0.7.9/src/weapon/gnu.h <==
/******************************************************************************
 *  Wormux is a convivial mass murder game.
 *  Copyright (C) 2001-2004 Lawrence Azzoug.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 ******************************************************************************
 * Weapon gnu : a gnu jump in (more or less) random directions and explodes
 *****************************************************************************/

#ifndef GNU_H
#define GNU_H

#include <SDL.h>
#include "grenade.h"
#include "weapon.h"
#include "../graphic/sprite.h"
#include "../gui/progress_bar.h"
#include "../include/base.h"
#include "../object/physical_obj.h"

class GnuLauncher;

// The GNU
class Gnu : public WeaponProjectile
{
 private:
  int m_sens;
  int save_x, save_y;
 protected:
  void SignalOutOfMap();
public:
  Gnu(ExplosiveWeaponConfig& cfg,
      WeaponLauncher * p_launcher);
  void Shoot(double strength);
  void Refresh();
};

class GnuLauncher : public WeaponLauncher
{
public:
  GnuLauncher();
protected:
  WeaponProjectile * GetProjectileInstance();
};

#endif

==> wormux_0.8.5.orig.tar.gz: wormux-0.8.5/src/weapon/gnu.h <==
/******************************************************************************
 *  Wormux is a convivial mass murder game.
 *  Copyright (C) 2001-2009 Wormux Team.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 ******************************************************************************
 * Weapon gnu : a gnu jump in (more or less) random directions and explodes
 *****************************************************************************/

#ifndef GNU_H
#define GNU_H

#include "weapon/weapon_launcher.h"

class Gnu;

// The GNU
class GnuLauncher : public WeaponLauncher
{
private:
  Gnu *current_gnu;
  uint gnu_death_time;
public:
  GnuLauncher();

  virtual void SignalEndOfProjectile();
  virtual void SignalProjectileCollision() { };
  virtual void SignalProjectileDrowning() { };

  virtual bool IsInUse() const;

  // Key Shoot management
  virtual void HandleKeyPressed_Shoot(bool shift);
  virtual void HandleKeyRefreshed_Shoot(bool shift);
  virtual void HandleKeyReleased_Shoot(bool shift);

  void ExplosionFromNetwork(Point2d gnu_pos);

  void UpdateTranslationStrings();
  std::string GetWeaponWinString(const char *TeamName, uint items_count) const;

protected:
  virtual bool p_Shoot();
  virtual void Refresh();
  WeaponProjectile * GetProjectileInstance();
};

#endif
